BrowserHttpClientAdapter class

The default HttpClientAdapter for Web platforms.

Implemented types

Constructors

BrowserHttpClientAdapter()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
withCredentials ↔ bool
Whether to send credentials such as cookies or authorization headers for cross-site requests.
getter/setter pair

Methods

close({bool force = false}) → void
Closes the client.
override
fetch(RequestOptions options, Stream<Uint8List>? requestStream, Future<void>? cancelFuture) → Future<ResponseBody>
We should implement this method to make real http requests.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited